@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.102_02';
+our $VERSION = '0.102_03';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Aug 13 13:56:08 2018 GMT
+# on Thu Aug 16 15:09:04 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1759,7 +1759,7 @@ __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
 __PACKAGE__->status( add => 25346, iridium => 'D', 'Iridium 75', 'Decayed 2018-07-10' );
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
-__PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
+__PACKAGE__->status( add => 25432, iridium => '-', 'Iridium 76', 'Tumbling' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
 __PACKAGE__->status( add => 25468, iridium => 'D', 'Iridium 81', 'Decayed 2018-07-17' );
 __PACKAGE__->status( add => 25469, iridium => 'D', 'Iridium 80', 'Decayed 2018-08-12' );
@@ -1784,8 +1784,8 @@ __PACKAGE__->status( add => 27451, iridium => '-', 'Iridium 98', 'Tumbling' );
 
 # Summary:
 # Operational [+]: 17
-#       Spare [S]: 14
-#    Tumbling [-]: 37
+#       Spare [S]: 13
+#    Tumbling [-]: 38
 #     Decayed [D]: 29
 
 1;
